Welcome to AEGIS – a software package for individual-based modeling of life history evolution.
In this visual interface you can run and inspect AEGIS simulations with access to documentation along the way.
